---
feature_story: FS_72_53_55_13
feature_title: show non-default options
feature_status: TEST
---

FS_72_40_53_00 fill control automatically sets default values (possibly based on some logic)<br/>
and these values are never interrogated.

However, user still needs to know what were all other non-default options before default was picked.<br/>
These options should be shown by `func_id_query_enum_items` FS_02_25_41_81 command.

